@@ -5,19 +5,19 @@ from .Fixlet import Fixlet
 from .Analysis import Analysis
 from .utils import BASELINE_CONTENT_TYPE_PATTERN
 
-logging.basicConfig()
-logging.getLogger().setLevel(logging.INFO)
-
 
 class Baseline(dict):
 
-    def __init__(self, payload, **kwargs):
+    logging.basicConfig()
+    logging.getLogger().setLevel(logging.INFO)
+
+    def __init__(self, payload, *, log_level=logging.INFO, **kwargs):
         """
         :param payload: Takes in a http multtipart payload
         :param unique_id: Optional id for external tracking purposes, since there is nothing in the payload that
         identifies a unique version, timestamp or iteration. Modified dates do not have to be unique.
         """
-
+        logging.getLogger().setLevel(log_level)
 
         # todo: change this hack, need to get this working for from_json class method
         if payload == "":
@@ -67,6 +67,13 @@ class Baseline(dict):
                 except Exception as e:
                     logging.exception(e)
 
+            # Fixlets will share the same values
+            self.source_release_date = self.fixlets[0].source_release_date
+            self.modification_time = self.fixlets[0].modication_time
+            self.cis_benchmark = self.fixlets[0].benchmark_version
+            self.xccdf_benchmark = self.fixlets[0].xccdf_benchmark
+
+
     def __getattr__(self, attr):
         return self.get(attr)
 
@@ -180,6 +187,7 @@ class Baseline(dict):
     #     logging.getLogger().setLevel(logging.INFO)
 
 
+
 def find_type(payload):
     """Checks substring of payload to determine whether payload is """
     if "X-Fixlet-Type: Fixlet" in payload:
